/*******************************************************************************

  Copyright(c) 1999 - 2015 Intel Corporation. All rights reserved.
  
  This program is free software; you can redistribute it and/or modify it 
  under the terms of the GNU General Public License as published by the Free 
  Software Foundation; either version 2 of the License, or (at your option) 
  any later version.
  
  This program is distributed in the hope that it will be useful, but WITHOUT 
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or 
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for 
  more details.
  
  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 59 
  Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  
  The full GNU General Public License is included in this distribution in the
  file called LICENSE.
  
  Contact Information:
  e1000 mailing list <e1000-devel@lists.sourceforge.net>
  Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497

*******************************************************************************/

#include <stdio.h>
#include "ethregs.h"
#include "ixgbe_vf.h"
#include "ixgbe_mbx.h"


extern int clr;
extern int offset;

void dump_X540_registers(volatile void *mem, u32 size)
{
	unsigned int i, j, m, n;
	char name[24];

	for (i = 0; i < size; i += sizeof(u32)) {
		switch (i & 0xffffffff) {
		/* General Registers */
		case IXGBE_CTRL:
			sprintf(name, "CTRL"); break;
		case IXGBE_STATUS:	/* WO */
			sprintf(name, "STATUS"); break;
		case IXGBE_CTRL_EXT:
			sprintf(name, "CTRL_EXT"); break;
		case IXGBE_ESDP:
			sprintf(name, "ESDP"); break;
		case IXGBE_PHY_GPIO:
			sprintf(name, "PHY_GPIO"); break;
		case IXGBE_MAC_GPIO:
			sprintf(name, "MAC_GPIO"); break;
		case IXGBE_PHYINT_STATUS0:
			sprintf(name, "PHYINT_STATUS0"); break;
		case IXGBE_PHYINT_STATUS1:
			sprintf(name, "PHYINT_STATUS1"); break;
		case IXGBE_PHYINT_STATUS2:
			sprintf(name, "PHYINT_STATUS2"); break;
		case IXGBE_LEDCTL:
			sprintf(name, "LEDCTL"); break;
		case IXGBE_FRTIMER:
			sprintf(name, "FRTIMER"); break;
		case IXGBE_TCPTIMER:
			sprintf(name, "TCPTIMER"); break;

		/* NVM Registers */
		case IXGBE_EEC:
			sprintf(name, "EEC"); break;
		case IXGBE_EERD:
			sprintf(name, "EERD"); break;
		case IXGBE_FLA:
			sprintf(name, "FLA"); break;
		case IXGBE_EEMNGCTL:
			sprintf(name, "EEMNGCTL"); break;
		case IXGBE_EEMNGDATA:
			sprintf(name, "EEMNGDATA"); break;
		case IXGBE_FLMNGCTL:
			sprintf(name, "FLMNGCTL"); break;
		case IXGBE_FLMNGDATA:
			sprintf(name, "FLMNGDATA"); break;
		case IXGBE_FLMNGCNT:
			sprintf(name, "FLMNGCNT"); break;
		case IXGBE_FLOP:
			sprintf(name, "FLOP"); break;
		case IXGBE_GRC:
			sprintf(name, "GRC"); break;
		case IXGBE_SRAMREL:
			sprintf(name, "IXGBE_SRAMREL"); break;
		case IXGBE_PHYDBG:
			sprintf(name, "IXGBE_PHYDBG"); break;

		/* Interrupt Registers */
		case IXGBE_EICR:
			if (!clr) continue;
			sprintf(name, "EICR"); break;
		case IXGBE_EICS:	/* WO */
			sprintf(name, "EICS"); break;
		case IXGBE_EICS_EX(0):	/* WO */
			for (j=i, n=0; n<2; n++) {
				sprintf(name, "EICS[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_EIMS:
			sprintf(name, "EIMS"); break;
		case IXGBE_EIMS_EX(0):
			for (j=i, n=0; n<2; n++) {
				sprintf(name, "EIMS[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_EIMC:	/* WO */
			sprintf(name, "EIMC"); break;
		case IXGBE_EIMC_EX(0):
			for (j=i, n=0; n<2; n++) {
				sprintf(name, "EIMC[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_EIAC:
			sprintf(name, "EIAC"); break;
		case IXGBE_EIAM:
			sprintf(name, "EIAM"); break;
		case IXGBE_EIAM_EX(0):
			for (j=i, n=0; n<2; n++) {
				sprintf(name, "EIAM[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_EITR(0):
			for (j=i, n=0; n<24; n++) {
				sprintf(name, "EITR[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_EITR(24):
			for (j=i, n=24; n<128; n++) {
				sprintf(name, "EITR[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_EITRSEL:
			sprintf(name, "EITRSEL"); break;
		case IXGBE_IVAR(0):
			for (j=i, n=0; n<64; n++) {
				sprintf(name, "IVAR[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_IVAR_MISC:
			sprintf(name, "IVAR_MISC"); break;
		case IXGBE_PBACL(1):
			for (j=i, n=1; n<8; n++) {
				sprintf(name, "PBACL[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_RSCDBU:
			sprintf(name, "RSCDBU"); break;
		case IXGBE_RSCCTL(0):
			for (j=i, n=0; n<64; n++) {
				sprintf(name, "RSCCTL[%d]", n);
				printit32(j, name, mem);
				j += 0x40;
			}
			continue;
		case IXGBE_RSCCTL(64):
			for (j=i, n=64; n<128; n++) {
				sprintf(name, "RSCCTL[%d]", n);
				printit32(j, name, mem);
				j += 0x40;
			}
			continue;
		case IXGBE_GPIE:
			sprintf(name, "GPIE"); break;

		/* Flow Control Registers */
		case IXGBE_PFCTOP:
			sprintf(name, "PFCTOP"); break;
		case IXGBE_FCTTV(0):
			for (j=i, n=0; n<4; n++) {
				sprintf(name, "FCTTV[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_FCRTL_82599(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "FCRTL[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_FCRTH_82599(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "FCRTH[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_FCRTV:
			sprintf(name, "FCRTV"); break;
		case IXGBE_TFCS:
			sprintf(name, "TFCS"); break;
		case IXGBE_FCCFG:
			sprintf(name, "FCCFG"); break;

		/* Receive DMA Registers */
		case IXGBE_RDBAL(0):
			for (j=i, n=0; n<64; n++) {
				sprintf(name, "RDBAL[%d]", n);
				printit32(j, name, mem);
				j += 4;
				sprintf(name, "RDBAH[%d]", n);
				printit32(j, name, mem);
				j += 4;
				sprintf(name, "RDLEN[%d]", n);
				printit32(j, name, mem);
				j += 4;
				sprintf(name, "DCA_RXCTRL[%d]", n);
				printit32(j, name, mem);
				j += 4;
				sprintf(name, "RDH[%d]", n);
				printit32(j, name, mem);
				j += 4;
				sprintf(name, "SRRCTL[%d]", n);
				printit32(j, name, mem);
				j += 4;
				sprintf(name, "RDT[%d]", n);
				printit32(j, name, mem);
				j += 16;
				sprintf(name, "RXDCTL[%d]", n);
				printit32(j, name, mem);
				j += 24;
			}
			continue;
		case IXGBE_RDBAL(64):
			for (j=i, n=64; n<128; n++) {
				sprintf(name, "RDBAL[%d]", n);
				printit32(j, name, mem);
				j += 4;
				sprintf(name, "RDBAH[%d]", n);
				printit32(j, name, mem);
				j += 4;
				sprintf(name, "RDLEN[%d]", n);
				printit32(j, name, mem);
				j += 4;
				sprintf(name, "DCA_RXCTRL[%d]", n);
				printit32(j, name, mem);
				j += 4;
				sprintf(name, "RDH[%d]", n);
				printit32(j, name, mem);
				j += 4;
				sprintf(name, "SRRCTL[%d]", n);
				printit32(j, name, mem);
				j += 4;
				sprintf(name, "RDT[%d]", n);
				printit32(j, name, mem);
				j += 16;
				sprintf(name, "RXDCTL[%d]", n);
				printit32(j, name, mem);
				j += 24;
			}
			continue;
		case IXGBE_RDRXCTL:
			sprintf(name, "RDRXCTL"); break;
		case IXGBE_RXPBSIZE(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "RXPBSIZE[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_RXCTRL:
			sprintf(name, "RXCTRL"); break;

		/* Receive Registers */
		case IXGBE_RXCSUM:
			sprintf(name, "RXCSUM"); break;
		case IXGBE_RFCTL:
			sprintf(name, "RFCTL"); break;
		case IXGBE_MTA(0):
			for (j=i, n=0; n<128; n++) {
				sprintf(name, "MTA[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_RAL(0):
			for (j=i, n=0; n<16; n++) {
				sprintf(name, "RAL[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
				sprintf(name, "RAH[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_RAL(16):
			for (j=i, n=16; n<128; n++) {
				sprintf(name, "RAL[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
				sprintf(name, "RAH[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_MPSAR_LO(0):
			for (j=i, n=0; n<256; n++) {
				sprintf(name, "MPSAR[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_PSRTYPE(0):
			for (j=i, n=0; n<16; n++) {
				sprintf(name, "PSRTYPE[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_PSRTYPE(16):
			for (j=i, n=16; n<64; n++) {
				sprintf(name, "PSRTYPE[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_VFTA(0):
			for (j=i, n=0; n<128; n++) {
				sprintf(name, "VFTA[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_FCTRL:
			sprintf(name, "FCTRL"); break;
		case IXGBE_VLNCTRL:
			sprintf(name, "VLNCTRL"); break;
		case IXGBE_MCSTCTRL:
			sprintf(name, "MCSTCTRL"); break;
		case IXGBE_MRQC:
			sprintf(name, "MRQC"); break;
		case IXGBE_MTQC:
			sprintf(name, "MTQC"); break;
		case IXGBE_RQTC:
			sprintf(name, "RQTC"); break;
		case IXGBE_VMD_CTL:
			sprintf(name, "VMD_CTL"); break;
		case IXGBE_IMIRVP:
			sprintf(name, "IMIRVP"); break;
		case IXGBE_RETA(0):
			for (j=i, n=0; n<32; n++) {
				sprintf(name, "RETA[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_SAQF(0):
			for (j=i, n=0; n<128; n++) {
				sprintf(name, "SAQF[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_DAQF(0):
			for (j=i, n=0; n<128; n++) {
				sprintf(name, "DAQF[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_SDPQF(0):
			for (j=i, n=0; n<128; n++) {
				sprintf(name, "SDPQF[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_FTQF(0):
			for (j=i, n=0; n<128; n++) {
				sprintf(name, "FTQF[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_ETQF(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "ETQF[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_ETQS(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "ETQS[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_SYNQF:
			sprintf(name, "SYNQF"); break;
		case IXGBE_RSSRK(0):
			for (j=i, n=0; n<10; n++) {
				sprintf(name, "RSSRK[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;

		/* Transmit DMA registers */
		case IXGBE_TDBAL(0):
			for (j=i, n=0; n<128; n++) {
				sprintf(name, "TDBAL[%d]", n);
				printit32(j, name, mem);
				j += 4;
				sprintf(name, "TDBAH[%d]", n);
				printit32(j, name, mem);
				j += 4;
				sprintf(name, "TDLEN[%d]", n);
				printit32(j, name, mem);
				j += 4;
				sprintf(name, "DCA_TXCTRL[%d]", n);
				printit32(j, name, mem);
				j += 4;
				sprintf(name, "TDH[%d]", n);
				printit32(j, name, mem);
				j += 8;
				sprintf(name, "TDT[%d]", n);
				printit32(j, name, mem);
				j += 16;
				sprintf(name, "TXDCTL[%d]", n);
				printit32(j, name, mem);
				j += 16;
				sprintf(name, "TDWBAL[%d]", n);
				printit32(j, name, mem);
				j += 4;
				sprintf(name, "TDWBAH[%d]", n);
				printit32(j, name, mem);
				j += 4;
			}
			continue;
		case IXGBE_DMATXCTL:
			sprintf(name, "DMATXCTL"); break;
		case IXGBE_TXPBSIZE(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "TXPBSIZE[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_MNGTXMAP:
			sprintf(name, "MNGTXMAP"); break;

		/* Wake up registers */
		case IXGBE_WUC:
			sprintf(name, "WUC"); break;
		case IXGBE_WUFC:
			sprintf(name, "WUFC"); break;
		case IXGBE_WUS:
			sprintf(name, "WUS"); break;
		case IXGBE_IPAV:
			sprintf(name, "IPAV"); break;
		case IXGBE_IP4AT:
			for (j=i, n=0; n<4; n++) {
				sprintf(name, "IP4AT[%d]", n);
				printit32(j, name, mem);
				j += (2 * sizeof(u32));
			}
			continue;
		case IXGBE_IP6AT:
			for (j=i, n=0; n<4; n++) {
				sprintf(name, "IP6AT[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_WUPL:
			sprintf(name, "WUPL"); break;
		case IXGBE_WUPM:
			for (j=i, n=0; n<32; n++) {
				sprintf(name, "WUPM[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_FHFT(0):
			for (j=i, m=0; m<4; m++) {
				for (n=0; n<32; n++) {
					sprintf(name, "FHFT[%d] DW%d", m, n);
					printit32(j, name, mem);
					j += sizeof(u32);
					n++;
					sprintf(name, "FHFT[%d] DW%d", m, n);
					printit32(j, name, mem);
					j += sizeof(u32);
					sprintf(name, "FHFT[%d] Mask[%d:%d]", m,
					        (n*4+3), ((n-1)*4));
					printit8(j, name, mem);
					j += sizeof(u32);
					if (n == 31) {
						sprintf(name, "FHFT[%d] Length", m);
						printit32(j, name, mem);
					}
					j += sizeof(u32);
				}
			}
			continue;

		/* Music registers */
		case IXGBE_RTRPCS:
			sprintf(name, "RTRPCS"); break;
		case IXGBE_RTTDCS:
			sprintf(name, "RTTDCS"); break;
		case IXGBE_RTTPCS:
			sprintf(name, "RTTPCS"); break;
		case IXGBE_RTRUP2TC:
			sprintf(name, "RTRUP2TC"); break;
		case IXGBE_RTTUP2TC:
			sprintf(name, "RTTUP2TC"); break;
		case IXGBE_RTTBCNRTT:
			sprintf(name, "RTTBCNRTT"); break;
		case IXGBE_RTRPT4C(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "RTRPT4C[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_RTRPT4S(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "RTRPT4S[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
#if 0
		case IXGBE_RTTDT2C(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "RTTDT2C[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
#endif
		case IXGBE_RTTDT2S(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "RTTDT2S[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_RTTPT2C(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "RTTPT2C[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_RTTPT2S(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "RTTPT2S[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
#if 0
		/*
		 * something is wrong with these registers
		 * and when read they cause ECC errors to be reported
		 */
		case IXGBE_RTTDT1C:
			sprintf(name, "RTTDT1C"); break;
		case IXGBE_RTTDT1S:
			sprintf(name, "RTTDT1S"); break;
#endif
		case IXGBE_RTTDTECC:
			sprintf(name, "RTTDTECC"); break;
		case IXGBE_RTFRTIMER:
			sprintf(name, "RTTFRTIMER"); break;

		/* Stats registers */
		case IXGBE_CRCERRS:
			if (!clr) continue;
			sprintf(name, "CRCERRS"); break;
		case IXGBE_ILLERRC:
			if (!clr) continue;
			sprintf(name, "ILLERRC"); break;
		case IXGBE_ERRBC:
			if (!clr) continue;
			sprintf(name, "ERRBC"); break;
		case IXGBE_MSPDC:
			if (!clr) continue;
			sprintf(name, "MSPDC"); break;
		case IXGBE_MPC(0):
			if (!clr) continue;
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "MPC[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_MLFC:
			if (!clr) continue;
			sprintf(name, "MLFC"); break;
		case IXGBE_MRFC:
			if (!clr) continue;
			sprintf(name, "MRFC"); break;
		case IXGBE_RLEC:
			if (!clr) continue;
			sprintf(name, "RLEC"); break;
		case IXGBE_LXONTXC:
			if (!clr) continue;
			sprintf(name, "LXONTXC"); break;
		case IXGBE_LXONRXC:
			if (!clr) continue;
			sprintf(name, "LXONRXC"); break;
		case IXGBE_LXOFFTXC:
			if (!clr) continue;
			sprintf(name, "LXOFFTXC"); break;
		case IXGBE_LXOFFRXC:
			if (!clr) continue;
			sprintf(name, "LXOFFRXC"); break;
		case IXGBE_PXONTXC(0):
			if (!clr) continue;
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "PXONTXC[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_PXONRXC(0):
			if (!clr) continue;
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "PXONRXC[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_PXOFFTXC(0):
			if (!clr) continue;
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "PXOFFTXC[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_PXOFFRXC(0):
			if (!clr) continue;
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "PXOFFRXC[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_PRC64:
			if (!clr) continue;
			sprintf(name, "PRC64"); break;
		case IXGBE_PRC127:
			if (!clr) continue;
			sprintf(name, "PRC127"); break;
		case IXGBE_PRC255:
			if (!clr) continue;
			sprintf(name, "PRC255"); break;
		case IXGBE_PRC511:
			if (!clr) continue;
			sprintf(name, "PRC511"); break;
		case IXGBE_PRC1023:
			if (!clr) continue;
			sprintf(name, "PRC1023"); break;
		case IXGBE_PRC1522:
			if (!clr) continue;
			sprintf(name, "PRC1522"); break;
		case IXGBE_GPRC:
			if (!clr) continue;
			sprintf(name, "GPRC"); break;
		case IXGBE_BPRC:
			if (!clr) continue;
			sprintf(name, "BPRC"); break;
		case IXGBE_MPRC:
			if (!clr) continue;
			sprintf(name, "MPRC"); break;
		case IXGBE_GPTC:
			if (!clr) continue;
			sprintf(name, "GPTC"); break;
		case IXGBE_GORCL:
			if (!clr) continue;
			sprintf(name, "GORCL"); break;
		case IXGBE_GORCH:
			if (!clr) continue;
			sprintf(name, "GORCH"); break;
		case IXGBE_GOTCL:
			if (!clr) continue;
			sprintf(name, "GOTCL"); break;
		case IXGBE_GOTCH:
			if (!clr) continue;
			sprintf(name, "GOTCH"); break;
		case IXGBE_RNBC(0):
			if (!clr) continue;
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "RNBC[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_RUC:
			if (!clr) continue;
			sprintf(name, "RUC"); break;
		case IXGBE_RFC:
			if (!clr) continue;
			sprintf(name, "RFC"); break;
		case IXGBE_ROC:
			if (!clr) continue;
			sprintf(name, "ROC"); break;
		case IXGBE_RJC:
			if (!clr) continue;
			sprintf(name, "RJC"); break;
		case IXGBE_MNGPRC:
			if (!clr) continue;
			sprintf(name, "MNGPRC"); break;
		case IXGBE_MNGPDC:
			if (!clr) continue;
			sprintf(name, "MNGPDC"); break;
		case IXGBE_MNGPTC:
			if (!clr) continue;
			sprintf(name, "MNGPTC"); break;
		case IXGBE_TORL:
			if (!clr) continue;
			sprintf(name, "TORL"); break;
		case IXGBE_TORH:
			if (!clr) continue;
			sprintf(name, "TORH"); break;
		case IXGBE_TPR:
			if (!clr) continue;
			sprintf(name, "TPR"); break;
		case IXGBE_TPT:
			if (!clr) continue;
			sprintf(name, "TPT"); break;
		case IXGBE_PTC64:
			if (!clr) continue;
			sprintf(name, "PTC64"); break;
		case IXGBE_PTC127:
			if (!clr) continue;
			sprintf(name, "PTC127"); break;
		case IXGBE_PTC255:
			if (!clr) continue;
			sprintf(name, "PTC255"); break;
		case IXGBE_PTC511:
			if (!clr) continue;
			sprintf(name, "PTC511"); break;
		case IXGBE_PTC1023:
			if (!clr) continue;
			sprintf(name, "PTC1023"); break;
		case IXGBE_PTC1522:
			if (!clr) continue;
			sprintf(name, "PTC1522"); break;
		case IXGBE_MPTC:
			if (!clr) continue;
			sprintf(name, "MPTC"); break;
		case IXGBE_BPTC:
			if (!clr) continue;
			sprintf(name, "BPTC"); break;
		case IXGBE_XEC:
			if (!clr) continue;
			sprintf(name, "XEC"); break;
		case IXGBE_RQSMR(0):
			for (j=i, n=0; n<32; n++) {
				sprintf(name, "RQSMR[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_TQSM(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "TQSM[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_QPRC(0):
			if (!clr) continue;
			for (j=i, n=0; n<16; n++) {
				sprintf(name, "QPRC[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
				sprintf(name, "QBRC[%d]", n);
				printit32(j, name, mem);
				j += 0x3c;
			}
			continue;
		case IXGBE_QPTC(0):
			if (!clr) continue;
			for (j=i, n=0; n<16; n++) {
				sprintf(name, "QPTC[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
				sprintf(name, "QBTC[%d]", n);
				printit32(j, name, mem);
				j += 0x3c;
			}
			continue;

		/* Management */
		case IXGBE_MAVTV(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "MAVTV[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_MFUTP(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "MFUTP[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_MANC:
			sprintf(name, "MANC"); break;
		case IXGBE_MFVAL:
			sprintf(name, "MFVAL"); break;
		case IXGBE_MANC2H:
			sprintf(name, "MAN2CH"); break;
		case IXGBE_MDEF(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "MDEF[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_MIPAF:
			sprintf(name, "MIPAF"); break;
		case IXGBE_MMAL(0):
			for (j=i, n=0; n<4; n++) {
				sprintf(name, "MMAL[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
				sprintf(name, "MMAH[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_FTFT:
			for (j=i, m=0; m<4; m++) {
				for (n=0; n<32; n++) {
					sprintf(name, "FTFT[%d] DW%d", m, n);
					printit32(j, name, mem);
					j += sizeof(u32);
					n++;
					sprintf(name, "FTFT[%d] DW%d", m, n);
					printit32(j, name, mem);
					j += sizeof(u32);
					sprintf(name, "FTFT[%d] Mask[%d:%d]", m,
					        (n*4+3), ((n-1)*4));
					printit8(j, name, mem);
					j += sizeof(u32);
					if (n == 31) {
						sprintf(name, "FTFT[%d] Length", m);
						printit32(j, name, mem);
					}
					j += sizeof(u32);
				}
			}
			continue;

		/* ARC Subsystem registers */
#if 0
		case IXGBE_HICR:
			sprintf(name, "HICR"); break;
#endif
		case IXGBE_FWSTS:
			sprintf(name, "FWSTS"); break;
		case IXGBE_HSMC0R:
			sprintf(name, "HSMCOR"); break;
		case IXGBE_HSMC1R:
			sprintf(name, "HSMC1R"); break;
		case IXGBE_SWSR:
			sprintf(name, "SWSR"); break;
		case IXGBE_HFDR:
			sprintf(name, "HFDR"); break;
		case IXGBE_FLEX_MNG:
			for (j=i, n=0; n<447; n++) {
				sprintf(name, "FLEX_MNG[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;

		/* Time Sync Registers */
		case IXGBE_TSYNCRXCTL:
			sprintf(name, "TSYNCRXCTL"); break;
		case IXGBE_RXSTMPL:
			sprintf(name, "RXSTMPL"); break;
		case IXGBE_RXSTMPH:
			sprintf(name, "RXSTMPH"); break;
		case IXGBE_RXSATRL:
			sprintf(name, "RXSATRL"); break;
		case IXGBE_RXSATRH:
			sprintf(name, "RXSATRH"); break;
		case IXGBE_RXMTRL:
			sprintf(name, "RXMTRL"); break;
		case IXGBE_TSYNCTXCTL:
			sprintf(name, "TSYNCTXCTL"); break;
		case IXGBE_TXSTMPL:
			sprintf(name, "TXSTMPL"); break;
		case IXGBE_TXSTMPH:
			sprintf(name, "TXSTMPH"); break;
		case IXGBE_SYSTIML:
			sprintf(name, "SYSTIML"); break;
		case IXGBE_SYSTIMH:
			sprintf(name, "SYSTIMH"); break;
		case IXGBE_TIMINCA:
			sprintf(name, "TIMINCA"); break;
		case IXGBE_TIMADJL:
			sprintf(name, "TIMADJL"); break;
		case IXGBE_TIMADJH:
			sprintf(name, "TIMADJH"); break;
		case IXGBE_TSAUXC:
			sprintf(name, "TSAUXC"); break;
		case IXGBE_TRGTTIML0:
			sprintf(name, "TRGTTIML0"); break;
		case IXGBE_TRGTTIMH0:
			sprintf(name, "TRGTTIMH0"); break;
		case IXGBE_TRGTTIML1:
			sprintf(name, "TRGTTIML1"); break;
		case IXGBE_TRGTTIMH1:
			sprintf(name, "TRGTTIMH1"); break;
		case IXGBE_FREQOUT0:
			sprintf(name, "FREQOUT0"); break;
		case IXGBE_FREQOUT1:
			sprintf(name, "FREQOUT1"); break;
		case IXGBE_AUXSTMPL0:
			sprintf(name, "AUXSTMPL0"); break;
		case IXGBE_AUXSTMPH0:
			sprintf(name, "AUXSTMPH0"); break;
		case IXGBE_AUXSTMPL1:
			sprintf(name, "AUXSTMPL1"); break;
		case IXGBE_AUXSTMPH1:
			sprintf(name, "AUXSTMPH1"); break;

		/* PCI-E registers */
		case IXGBE_GCR_EXT:
			sprintf(name, "GCR_EXT"); break;
		case IXGBE_PHYADR_82599:
			sprintf(name, "PHYADR_82599"); break;
		case IXGBE_PHYDAT_82599:
			sprintf(name, "PHYDAT_82599"); break;
		case IXGBE_PHYCTL_82599:
			sprintf(name, "PHYCTL_82599"); break;
		case IXGBE_PBACLR_82599:
			sprintf(name, "PBACLR_82599"); break;
		case IXGBE_CIAA_82599:
			sprintf(name, "CIAA_82599"); break;
		case IXGBE_CIAD_82599:
			sprintf(name, "CIAD_82599"); break;
		case IXGBE_PICAUSE:
			sprintf(name, "PICAUSE"); break;
		case IXGBE_PIENA:
			sprintf(name, "PIENA"); break;
		case IXGBE_CDQ_MBR_82599:
			sprintf(name, "CDQ_MBR_82599"); break;
		case IXGBE_MISC_REG_82599:
			sprintf(name, "MISC_REG_82599"); break;
		case IXGBE_ECC_CTRL_0_82599:
			sprintf(name, "ECC_CTRL_0_82599"); break;
		case IXGBE_ECC_CTRL_1_82599:
			sprintf(name, "ECC_CTRL_1_82599"); break;
		case IXGBE_ECC_STATUS_82599:
			sprintf(name, "ECC_STATUS_82599"); break;
		case IXGBE_BAR_CTRL_82599:
			sprintf(name, "BAR_CTRL_82599"); break;

		case IXGBE_GCR:
			sprintf(name, "GCR"); break;
		case IXGBE_GSCL_1:
			sprintf(name, "GSCL_1"); break;
		case IXGBE_GSCL_2:
			sprintf(name, "GSCL_2"); break;
		case IXGBE_GSCL_5_82599:
			sprintf(name, "GSCL_5_82599"); break;
		case IXGBE_GSCL_6_82599:
			sprintf(name, "GSCL_6_82599"); break;
		case IXGBE_GSCL_7_82599:
			sprintf(name, "GSCL_7_82599"); break;
		case IXGBE_GSCL_8_82599:
			sprintf(name, "GSCL_8_82599"); break;
		case IXGBE_GSCN_0:
			sprintf(name, "GSCN_0"); break;
		case IXGBE_GSCN_1:
			sprintf(name, "GSCN_1"); break;
		case IXGBE_GSCN_2:
			sprintf(name, "GSCN_2"); break;
		case IXGBE_GSCN_3:
			sprintf(name, "GSCN_3"); break;
		case IXGBE_FACTPS:
			sprintf(name, "FACTPS"); break;
		case IXGBE_FWSM:
			sprintf(name, "FWSM"); break;
		case IXGBE_MREVID:
			sprintf(name, "MREVID"); break;
		case IXGBE_DCA_ID:
			sprintf(name, "DCA_ID"); break;
		case IXGBE_DCA_CTRL:
			sprintf(name, "DCA_CTRL"); break;

		/* Diagnostic Registers */
		case IXGBE_RXDBUECC:
			sprintf(name, "RXDBUECC"); break;
		case IXGBE_RXDBUEST:
			sprintf(name, "RXDBUEST"); break;
		case IXGBE_TXDBUECC:
			sprintf(name, "TXDBUECC"); break;
		case IXGBE_TXDBUEST:
			sprintf(name, "RXDBUECC"); break;
		case IXGBE_TDHMPN2:
			sprintf(name, "TDHMPN2"); break;
		case IXGBE_TIC_DW2(0):
			for (j=i, n=0; n<4; n++) {
				sprintf(name, "TIC_DW2[%d]",n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_TDPROBE:
			sprintf(name, "TDPROBE"); break;
		case IXGBE_TXBUFCTRL:
			sprintf(name, "TXBUFCTRL"); break;
		case IXGBE_TXBUFDATA0:
			for (j=i, n=0; n<4; n++) {
				sprintf(name, "TXBUFDATA[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		/* TXBUFDATA should extend to 8 dwords */
		case IXGBE_RXBUFCTRL:
			sprintf(name, "RXBUFCTRL"); break;
		case IXGBE_RXBUFDATA0:
			for (j=i, n=0; n<4; n++) {
				sprintf(name, "RXBUFDATA[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		/* RXBUFDATA should extend to 8 dwords */
		case IXGBE_PCIE_DIAG(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "PCIE_DIAG[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_RFVAL:
			sprintf(name, "RFVAL"); break;
		case IXGBE_MDFTC1:
			sprintf(name, "MDFTC1"); break;
		case IXGBE_MDFTC2:
			sprintf(name, "MDFTC2"); break;
		case IXGBE_MDFTFIFO1:
			sprintf(name, "MDFTFIFO1"); break;
		case IXGBE_MDFTFIFO2:
			sprintf(name, "MDFTFIFO2"); break;
		case IXGBE_MDFTS:
			sprintf(name, "MDFTS"); break;

		case IXGBE_RXWRPTR(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "RXWRPTR[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_RXUSED(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "RXUSED[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_RXRDPTR(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "RXRDPTR[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_RXRDWRPTR(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "RXRDWRPTR[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;

		/* MAC Registers */
		case IXGBE_PCS1GCFIG:
			sprintf(name, "PCS1GCFIG"); break;
		case IXGBE_PCS1GLCTL:
			sprintf(name, "PCS1GLCTL"); break;
		case IXGBE_PCS1GLSTA:
			sprintf(name, "PCS1GLSTA"); break;
		case IXGBE_PCS1GDBG0:
			sprintf(name, "PCS1GDBG0"); break;
		case IXGBE_PCS1GDBG1:
			sprintf(name, "PCS1GDBG1"); break;
		case IXGBE_PCS1GANA:
			sprintf(name, "PCS1GANA"); break;
		case IXGBE_PCS1GANLP:
			sprintf(name, "PCS1GANLP"); break;
		case IXGBE_PCS1GANNP:
			sprintf(name, "PCS1GANNP"); break;
		case IXGBE_PCS1GANLPNP:
			sprintf(name, "PCS1GANLPNP"); break;
		case IXGBE_HLREG0:
			sprintf(name, "HLREG0"); break;
		case IXGBE_HLREG1:
			sprintf(name, "HLREG1"); break;
		case IXGBE_PAP:
			sprintf(name, "PAP"); break;
		case IXGBE_MACA:
			sprintf(name, "MACA"); break;
		case IXGBE_APAE:
			sprintf(name, "APAE"); break;
		case IXGBE_ARD:
			sprintf(name, "ARD"); break;
		case IXGBE_AIS:
			sprintf(name, "AIS"); break;
		case IXGBE_MSCA:
			sprintf(name, "MSCA"); break;
		case IXGBE_MSRWD:
			sprintf(name, "MSRWD"); break;
		case IXGBE_MAXFRS:
			sprintf(name, "MAXFRS"); break;
		case IXGBE_TREG:
			sprintf(name, "TREG"); break;
		case IXGBE_PCSS1:
			sprintf(name, "PCSS1"); break;
		case IXGBE_PCSS2:
			sprintf(name, "PCSS2"); break;
		case IXGBE_XPCSS:
			sprintf(name, "XPCSS"); break;
		case IXGBE_MFLCN:
			sprintf(name, "MFLCN"); break;
		case IXGBE_SERDESC:
			sprintf(name, "SERDESC"); break;
		case IXGBE_MACS:
			sprintf(name, "MACS"); break;
		case IXGBE_AUTOC:
			sprintf(name, "AUTOC"); break;
		case IXGBE_LINKS:
			sprintf(name, "LINKS"); break;
		case IXGBE_AUTOC2:
			sprintf(name, "AUTOC2"); break;
		case IXGBE_AUTOC3:
			sprintf(name, "AUTOC3"); break;
		case IXGBE_ANLP1:
			sprintf(name, "ANLP1"); break;
		case IXGBE_ANLP2:
			sprintf(name, "ANLP2"); break;

		case IXGBE_VT_CTL:
			sprintf(name, "VT_CTL"); break;
		case IXGBE_VFRE(0):
			for (j=i, n=0; n<2; n++) {
				sprintf(name, "VFRE[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_VFTE(0):
			for (j=i, n=0; n<2; n++) {
				sprintf(name, "VFTE[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_VMOLR(0):
			for (j=i, n=0; n<64; n++) {
				sprintf(name, "VMOLR[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_VLVF(0):
			for (j=i, n=0; n<64; n++) {
				sprintf(name, "VLVF[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_VLVFB(0):
			for (j=i, n=0; n<128; n++) {
				sprintf(name, "VLVFB[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_UTA(0):
			for (j=i, n=0; n<128; n++) {
				sprintf(name, "UTA[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_VMRVLAN(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "VMRVLAN[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_VMRVM(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "VMRVM[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;

		/* Flow Director registers */
		case IXGBE_FDIRCTRL:
			sprintf(name, "FDIRCTRL"); break;
		case IXGBE_FDIRHKEY:
			sprintf(name, "FDIRHKEY"); break;
		case IXGBE_FDIRSKEY:
			sprintf(name, "FDIRSKEY"); break;
		/* Flow Director Mask registers */
		case IXGBE_FDIRDIP4M:
			sprintf(name, "FDIRDIP4M"); break;
		case IXGBE_FDIRSIP4M:
			sprintf(name, "FDIRSIP4M"); break;
		case IXGBE_FDIRTCPM:
			sprintf(name, "FDIRTCPM"); break;
		case IXGBE_FDIRUDPM:
			sprintf(name, "FDIRUDPM"); break;
		case IXGBE_FDIRIP6M:
			sprintf(name, "FDIRIP6M"); break;
		case IXGBE_FDIRM:
			sprintf(name, "FDIRM"); break;
		/* Flow Director Statistics */
		case IXGBE_FDIRFREE:
			sprintf(name, "FDIRFREE"); break;
		case IXGBE_FDIRLEN:
			sprintf(name, "FDIRLEN"); break;
		case IXGBE_FDIRUSTAT:
			sprintf(name, "FDIRUSTAT"); break;
		case IXGBE_FDIRFSTAT:
			sprintf(name, "FDIRFSTAT"); break;
		case IXGBE_FDIRMATCH:
			sprintf(name, "FDIRMATCH"); break;
		case IXGBE_FDIRMISS:
			sprintf(name, "FDIRMISS"); break;
		/* Flow Director Filter Programming registers */
		case IXGBE_FDIRIPSA:
			sprintf(name, "FDIRIPSA"); break;
		case IXGBE_FDIRIPDA:
			sprintf(name, "FDIRIPDA"); break;
		case IXGBE_FDIRPORT:
			sprintf(name, "FDIRPORT"); break;
		case IXGBE_FDIRVLAN:
			sprintf(name, "FDIRVLAN"); break;
		case IXGBE_FDIRHASH:
			sprintf(name, "FDIRHASH"); break;
		case IXGBE_FDIRCMD:
			sprintf(name, "FDIRCMD"); break;
		case IXGBE_MACC:
			sprintf(name, "MACC"); break;

		default:
			continue;
		}
		printit32(i, name, mem);
	}
}

void dump_X540vf_registers(volatile void *mem, u32 size)
{
	unsigned int i, j, n;
	char name[24];

	for (i = 0; i < size; i += sizeof(u32)) {
		switch (i & 0xffffffff) {
		/* General Registers */
		case IXGBE_VFCTRL:
			sprintf(name, "VFCTRL"); break;
		case IXGBE_VFSTATUS:	/* WO */
			sprintf(name, "VFSTATUS"); break;
		case IXGBE_VFLINKS:
			sprintf(name, "VFLINKS"); break;
		case IXGBE_VFFRTIMER:
			sprintf(name, "VFFRTIMER"); break;
		case IXGBE_VFRXMEMWRAP:
			sprintf(name, "VFRXMEMWRAP"); break;

		/* Mailbox Registers */
		case IXGBE_VFMAILBOX:
			if (!clr) continue;
			sprintf(name, "VFMAILBOX"); break;
		case IXGBE_VFMBMEM:
			for (j=i, n=0; n<16; n++) {
				sprintf(name, "VFMBMEM[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;

		/* Interrupt Registers */
		case IXGBE_VTEICR:
			if (!clr) continue;
			sprintf(name, "VTEICR"); break;
		case IXGBE_VTEICS:	/* WO */
			sprintf(name, "VTEICS"); break;
		case IXGBE_VTEIMS:
			sprintf(name, "VTEIMS"); break;
		case IXGBE_VTEIMC:
			sprintf(name, "VTEIMC"); break;
		case IXGBE_VTEIAC:
			sprintf(name, "VTEIAC"); break;
		case IXGBE_VTEIAM:
			sprintf(name, "VTEIAM"); break;
		case IXGBE_VTEITR(0):
			for (j=i, n=0; n<2; n++) {
				sprintf(name, "VTEITR[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_VTIVAR(0):
			for (j=i, n=0; n<4; n++) {
				sprintf(name, "VTIVAR[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_VTIVAR_MISC:
			sprintf(name, "VTIVAR_MISC"); break;

		/* Receive DMA Registers */
		case IXGBE_VFRDBAL(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "VFRDBAL[%d]", n);
				printit32(j, name, mem);
				j += 4;
				sprintf(name, "VFRDBAH[%d]", n);
				printit32(j, name, mem);
				j += 4;
				sprintf(name, "VFRDLEN[%d]", n);
				printit32(j, name, mem);
				j += 4;
				sprintf(name, "VFDCA_RXCTRL[%d]", n);
				printit32(j, name, mem);
				j += 4;
				sprintf(name, "VFRDH[%d]", n);
				printit32(j, name, mem);
				j += 4;
				sprintf(name, "VFSRRCTL[%d]", n);
				printit32(j, name, mem);
				j += 4;
				sprintf(name, "VFRDT[%d]", n);
				printit32(j, name, mem);
				j += 16;
				sprintf(name, "VFRXDCTL[%d]", n);
				printit32(j, name, mem);
				j += 24;
			}
			continue;

		/* Receive Registers */
		case IXGBE_VFPSRTYPE:
			sprintf(name, "VFPSRTYPE"); break;

		/* Transmit DMA registers */
		case IXGBE_VFTDBAL(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "VFTDBAL[%d]", n);
				printit32(j, name, mem);
				j += 4;
				sprintf(name, "VFTDBAH[%d]", n);
				printit32(j, name, mem);
				j += 4;
				sprintf(name, "VFTDLEN[%d]", n);
				printit32(j, name, mem);
				j += 4;
				sprintf(name, "VFDCA_TXCTRL[%d]", n);
				printit32(j, name, mem);
				j += 4;
				sprintf(name, "VFTDH[%d]", n);
				printit32(j, name, mem);
				j += 8;
				sprintf(name, "VFTDT[%d]", n);
				printit32(j, name, mem);
				j += 16;
				sprintf(name, "VFTXDCTL[%d]", n);
				printit32(j, name, mem);
				j += 16;
				sprintf(name, "VFTDWBAL[%d]", n);
				printit32(j, name, mem);
				j += 4;
				sprintf(name, "VFTDWBAH[%d]", n);
				printit32(j, name, mem);
				j += 4;
			}
			continue;

		default:
			continue;
		}
		printit32(i, name, mem);
	}
}

// vi:ts=4:sw=4:ht=4:
